#include "OpenGlPainter.h"

#include "DrawingContext.h"
#include "DrawingSurface.h"
#include "Scene.h"
#include "TriMesh.h"

#ifdef _WIN32
#include <windows.h>
#endif

#include <GL/gl.h>

#include <iostream>

void OpenGlPainter::paint(DrawingContext* context)
{
    auto surface = context->getSurface();
    const auto width = double(surface->getWidth());
    const auto height = double(surface->getHeight());

    const auto num_mesh = context->getScene()->getNumMeshes();

    glClearColor(0.4, 0.4, 0.4, 0.4);
    glClear(GL_COLOR_BUFFER_BIT);

    glOrtho(-1.0, 1.0, -1.0, 1.0, -1.0, 1.0);

    for (std::size_t idx=0; idx<num_mesh; idx++)
    {
        auto mesh = context->getScene()->getMesh(idx);
        const auto faces =  mesh->getFaceVertices();

        glColor3f(1.0, 0.0, 1.0);

        for (const auto& face : faces)
        {
            glBegin(GL_TRIANGLES);
            double x0 = 2.0*face[0].getX() / width - 1.0;
            double y0 = 2.0*face[0].getY() / height - 1.0;

            double x1 = 2.0*face[1].getX() / width - 1.0;
            double y1 = 2.0*face[1].getY() / height - 1.0;

            double x2 = 2.0*face[2].getX() / width - 1.0;
            double y2 = 2.0*face[2].getY() / height - 1.0;

            glVertex3f(x0, y0, 0);
            glVertex3f(x1, y1, 0);
            glVertex3f(x2, y2, 0);

            glEnd();
        }
    }

    glFlush();
}
